#!/bin/bash

# Damien 20080305 : suppression des accents 
# SAS 20070719 : menus correctifs

##
# Le fichier de script SQL a ete obtenu a partir de druid
# Il y a quelques suppositions de dpart
#

# Variables
SQLDIR=.
BINDIR=base/bin
SCHEMA=schema/schema_cave.sql
DBNAME=cave
DBUSER=caviste
export DBNAME
# S'assurer que le client est compatible avec les locales
# On ne connait pas la locale de la base, a priori
# Il semblerait toutefois qu'un client en latin9 sache afficher
# des infos de base en UTF8
export PGCLIENTENCODING=latin9

#SUPER_POSTGRES='sudo su postgres -c'

cd `dirname $0`

# si l'IP de la machine n'est pas precisee, on utilise 'localhost'
# L'interet etant d'utiliser l'information par la suite !
export PGHOST=${1:-localhost}

# Si la base existe, on la droppe avant de la creer
# Il faut que l'utilisateur courant soit un USER PG,
# on utilise donc postgres
RES=`echo "SELECT datname FROM pg_database WHERE datname='$DBNAME'" | psql -t template1 | awk '{print $1}'`
if [ "$RES" == "$DBNAME" ]; then
  echo "On droppe la base $DBNAME..."
  #$SUPER_POSTGRES "dropdb $DBNAME"
  dropdb $DBNAME
fi

# On supprime l'utilisateur DBUSER s'il existe
#RES=`echo "select rolname from pg_roles where rolname='$DBUSER'" | $SUPER_POSTGRES "psql -t template1" | awk '{print $1}'`
RES=`echo "select rolname from pg_roles where rolname='$DBUSER'" | psql -t template1 | awk '{print $1}'`
if [ "$RES" == "$DBUSER" ]; then
  echo "On droppe l'user $DBUSER..."
  #$SUPER_POSTGRES "dropuser $DBUSER"
  dropuser $DBUSER
fi

# Creation PG user
USER_OPTS="--no-superuser --no-createrole --no-createdb $DBUSER --pwprompt"

echo "On cree l'user $DBUSER..."
#$SUPER_POSTGRES "createuser $USER_OPTS"
createuser $USER_OPTS

echo "On cree la base $DBNAME..."
#$SUPER_POSTGRES "createdb --owner $DBUSER $DBNAME"
createdb --owner $DBUSER $DBNAME

RES=`echo "SELECT lanname FROM pg_language WHERE lanname='plpgsql'" | psql -t $DBNAME | awk '{print $1}'`
if [ "$RES" != "plpgsql" ]; then
	echo "On ajoute le langage plpgsql a $DBNAME..."
	#$SUPER_POSTGRES "createlang plpgsql $DBNAME"
	createlang plpgsql $DBNAME
fi

if [ -e $SCHEMA ] ; then

	# Creation du schema (TABLES, INDEX, SEQUENCES)
	echo "Creation du schema de la base de donnees"
	cat $SCHEMA \
		$SQLDIR/fonctions/peuple_vin.sql \
		$SQLDIR/fonctions/peuple_stock.sql \
		$SQLDIR/fonctions/trous_stock.sql \
		$SQLDIR/fonctions/trous_vin.sql \
		$SQLDIR/data/appellation_region.sql \
		$SQLDIR/data/data.sql|\
	psql -q -U $DBUSER $DBNAME

  #psql -q -U $DBUSER $DBNAME < $SCHEMA
 
  # creation des fonctions
  #psql -q -U $DBUSER $DBNAME < $SQLDIR/fonctions/peuple_vin.sql
  #psql -q -U $DBUSER $DBNAME < $SQLDIR/fonctions/peuple_stock.sql
  #psql -q -U $DBUSER $DBNAME < $SQLDIR/fonctions/trous_stock.sql
  #psql -q -U $DBUSER $DBNAME < $SQLDIR/fonctions/trous_vin.sql
 
  # Insertion des donnees
  #psql -q -U $DBUSER $DBNAME < $SQLDIR/data/appellation_region.sql
  #psql -q -U $DBUSER $DBNAME < $SQLDIR/data/data.sql

else 
  echo "Le fichier $SCHEMA est absent."
  echo "Le schema de la base n'a pas ete charge !"
fi
